@@ -339,7 +339,7 @@ fn list_members(
 ) -> StdResult<MemberListResponse> {
     let limit = limit.unwrap_or(DEFAULT_LIMIT).min(MAX_LIMIT) as usize;
     let addr = maybe_addr(deps.api, start_after)?;
-    let start = addr.map(|addr| Bound::exclusive(addr.as_ref()));
+    let start = addr.as_ref().map(Bound::exclusive);
 
     let members = MEMBERS
         .range(deps.storage, start, None, Order::Ascending)
@@ -669,7 +669,7 @@ mod tests {
             }) => {
                 assert_eq!(contract_addr.as_str(), CW20_ADDRESS);
                 assert_eq!(funds.len(), 0);
-                let parsed: Cw20ExecuteMsg = from_slice(&msg).unwrap();
+                let parsed: Cw20ExecuteMsg = from_slice(msg).unwrap();
                 assert_eq!(
                     parsed,
                     Cw20ExecuteMsg::Transfer {
